==> fincast-0.0.5-sources.jar: io/fincast/household/impl/Liability.kt <==
package io.fincast.household.impl

import io.fincast.portfolio.ValueProviders.constValue
import io.fincast.portfolio.ValueProviders.eomBalance
import io.fincast.household.Valuable
import io.fincast.enums.ProductType
import io.fincast.enums.FundsAllocation
import io.fincast.portfolio.Portfolio
import io.fincast.portfolio.Position
import io.fincast.portfolio.PositionCompo
import io.fincast.enums.BookingKind
import io.fincast.enums.Periodicity
import io.fincast.portfolio.impl.YieldCompo

data class Liability(
	override val tag: String,
	override val reconBalance: Double = 0.0,
	val interestRate: Double = 0.0,
	val interestPeriodicity: Periodicity = Periodicity.YEARLY,
	val interestAllocation: FundsAllocation = FundsAllocation.DISBURSE,
) : Valuable {

	override val productType = ProductType.LIABILITY

	class Builder {
		private var tag: String? = null
		private var reconBalance: Double? = null
		private var interestRate: Double? = null
		private var interestPeriodicity: Periodicity? = null
		private var interestAllocation: FundsAllocation? = null
		fun tag(tag: String) = apply { this.tag = tag }
		fun reconBalance(reconBalance: Double) = apply { this.reconBalance = reconBalance }
		fun interestRate(interestRate: Double) = apply { this.interestRate = interestRate }
		fun interestPeriodicity(interestPeriodicity: Periodicity) = apply { this.interestPeriodicity = interestPeriodicity }
		fun interestAllocation(fundsAllocation: FundsAllocation) = apply { this.interestAllocation = fundsAllocation }
		fun build(): Liability {
			return Liability(
				tag = tag ?: throw IllegalArgumentException("tag is required"),
				reconBalance = reconBalance ?: 0.0,
				interestRate = interestRate ?: 0.0,
				interestPeriodicity = interestPeriodicity ?: Periodicity.YEARLY,
				interestAllocation = interestAllocation ?: FundsAllocation.DISBURSE,
			)
		}
	}

	override fun createCompos(portfolio: Portfolio, pos: Position): List<PositionCompo> {
		val compos: MutableList<PositionCompo> = mutableListOf()
		if (interestRate != 0.0) {
			compos.add(
				YieldCompo(
					position = pos,
					tag = "interest",
					amount = eomBalance(pos),
					yieldRate = constValue(interestRate),
					yieldPeriodicity = interestPeriodicity,
					bookingKind = BookingKind.INTEREST,
					fundsAllocation = interestAllocation,
				)
			)
		}
		return compos
	}

}

==> fincast-0.0.10-sources.jar: io/fincast/household/impl/Liability.kt <==
package io.fincast.household.impl

import io.fincast.enums.BookingKind
import io.fincast.enums.FundsAllocation
import io.fincast.enums.Periodicity
import io.fincast.enums.ProductType
import io.fincast.household.Valuable
import io.fincast.portfolio.Portfolio
import io.fincast.portfolio.Position
import io.fincast.portfolio.PositionCompo
import io.fincast.portfolio.ValueProviders.constValue
import io.fincast.portfolio.ValueProviders.eomBalance
import io.fincast.portfolio.impl.YieldCompo

data class Liability(
	override val tag: String,
	override val reconBalance: Double = 0.0,
	val interestRate: Double = 0.0,
	val interestPeriodicity: Periodicity = Periodicity.YEARLY,
	val interestAllocation: FundsAllocation = FundsAllocation.DISBURSE,
) : Valuable {

	override val productType = ProductType.LIABILITY

	class Builder {
		private var tag: String? = null
		private var reconBalance: Double? = null
		private var interestRate: Double? = null
		private var interestPeriodicity: Periodicity? = null
		private var interestAllocation: FundsAllocation? = null
		fun tag(tag: String) = apply { this.tag = tag }
		fun reconBalance(reconBalance: Double?) = apply { this.reconBalance = reconBalance }
		fun interestRate(interestRate: Double?) = apply { this.interestRate = interestRate }
		fun interestPeriodicity(interestPeriodicity: Periodicity?) = apply { this.interestPeriodicity = interestPeriodicity }
		fun interestAllocation(fundsAllocation: FundsAllocation?) = apply { this.interestAllocation = fundsAllocation }
		fun build(): Liability {
			return Liability(
				tag = tag ?: throw IllegalArgumentException("tag is required"),
				reconBalance = reconBalance ?: 0.0,
				interestRate = interestRate ?: 0.0,
				interestPeriodicity = interestPeriodicity ?: Periodicity.YEARLY,
				interestAllocation = interestAllocation ?: FundsAllocation.DISBURSE,
			)
		}
	}

	override fun createCompos(portfolio: Portfolio, pos: Position): List<PositionCompo> {
		val compos: MutableList<PositionCompo> = mutableListOf()
		if (interestRate != 0.0) {
			compos.add(
				YieldCompo(
					position = pos,
					tag = "interest",
					amount = eomBalance(pos),
					yieldRate = constValue(interestRate),
					yieldPeriodicity = interestPeriodicity,
					bookingKind = BookingKind.INTEREST,
					fundsAllocation = interestAllocation,
				)
			)
		}
		return compos
	}

}
